#ifndef API_CONTROLLER_HH
#define API_CONTROLLER_HH

#include <memory>
#include <pch.hh>
#include <mutex>
#include <semaphore>
#include <utility>
#include <unordered_map>
#include <queries.hh>
#include <local/imageHub/imageHub.hh>

using std::string;
using std::shared_ptr;

class apiController : public HttpController<apiController> {
private:
    string imagePath;
    DbClientPtr db;
    const string dbName = "default";
    shared_ptr<imageHub> ih;

public:
    METHOD_LIST_BEGIN
    ADD_METHOD_VIA_REGEX(apiController::getUploads, R"(^/uploads$)", Get);
    ADD_METHOD_VIA_REGEX(apiController::postUpload, R"(^/upload$)", Post);
    ADD_METHOD_VIA_REGEX(apiController::getImg, R"(^/img$)", Get);
    ADD_METHOD_VIA_REGEX(apiController::getImgFromId, R"(^/img/([^/.]+)$)", 
            Get);
    ADD_METHOD_VIA_REGEX(apiController::getRemove, R"(^/delete$)", Get);
    ADD_METHOD_VIA_REGEX(apiController::getRemoveFromId, 
            R"(^/delete/([^/.]+)$)", Get);
    ADD_METHOD_VIA_REGEX(apiController::getLike, R"(^/like$)", Get);
    ADD_METHOD_VIA_REGEX(apiController::getLikeFromId, R"(^/like/([^/.]+)$)", 
            Get);
    ADD_METHOD_VIA_REGEX(apiController::getTop, R"(^/top$)", Get);
    METHOD_LIST_END

    apiController();
    ~apiController();

    void getUploads(const HttpRequestPtr& req, Callback&& callback);
    void postUpload(const HttpRequestPtr& req, Callback&& callback);
    void getImg(const HttpRequestPtr& req, Callback&& callback);
    void getImgFromId(const HttpRequestPtr& req, Callback&& callback, 
            const string& sId);
    void getLike(const HttpRequestPtr& req, Callback&& callback);
    void getLikeFromId(const HttpRequestPtr& req, Callback&& callback, 
            const string& sId);
    void getTop(const HttpRequestPtr& req, Callback&& callback);
    void getRemove(const HttpRequestPtr& req, Callback&& callback);
    void getRemoveFromId(const HttpRequestPtr& req, Callback&& callback, 
            const string& sId);
};

#endif // API_CONTROLLER_HH
