#include <controllers/apiController.hh>

void apiController::getLike(const HttpRequestPtr& req, Callback&& callback)
{
    auto param = req->getParameters();
    if (param.find("q") == param.end()) {
        auto resp = HttpResponse::newNotFoundResponse();
        callback(resp);
        return;
    }
    auto hash = param["q"];
    if (!ih->checkExistHash(hash)) {
        auto resp = HttpResponse::newNotFoundResponse();
        callback(resp);
        return;
    }
    auto id = ih->getIdFromHash(hash);
    auto ip = req->peerAddr().toIp();
    db->execSqlAsync(queryInsertLike,
        [id, callback, this](const Result& result) {
            auto resp = HttpResponse::newHttpResponse();
            resp->setStatusCode(k200OK);
            if (result.affectedRows() > 0) {
                auto flags = ih->likeFromId(id);
                if(flags != 0) {
                    resp->setStatusCode(k500InternalServerError);
                    resp->setBody("something went wrong...");
                }
                else {
                    resp->setStatusCode(k200OK);
                    resp->setBody("Success");
                }
            }
            else {
                resp->setStatusCode(k200OK);
                resp->setBody("Already Liked");
            }
            callback(resp);
            return;
        },
        [callback](const DrogonDbException& e) {
            auto resp = HttpResponse::newHttpResponse();
            resp->setStatusCode(k500InternalServerError);
            resp->setBody("err uploading" + string(e.base().what()));
            callback(resp);
            return;
        },
        id,
        ip
    );
    // omit callback
}
