#include <controllers/apiController.hh>

void apiController::getRemove(const HttpRequestPtr &req, Callback &&callback)
{
    auto ip = req->peerAddr().toIp();
    auto param = req->getParameters();
    if (param.find("q") == param.end()) {
        auto resp = HttpResponse::newNotFoundResponse();
        callback(resp);
        return;
    }
    auto hash = param["q"];
    db->execSqlAsync(queryDeleteUpload,
        [hash, callback, this](const Result& result) {
            if (result.empty()) {
                auto resp = HttpResponse::newNotFoundResponse();
                callback(resp);
                return;
            }
            auto flags = ih->deleteHash(hash);
            auto resp = HttpResponse::newHttpResponse();
            if(flags > 0) {
                resp->setStatusCode(k500InternalServerError);
                resp->setBody("something went wrong...");
            }
            else {
                resp->setStatusCode(k200OK);
                resp->setBody("Success");
            }
            callback(resp);
            return;
        },
        [callback](const DrogonDbException& e) {
            auto resp = HttpResponse::newHttpResponse();
            resp->setStatusCode(k500InternalServerError);
            resp->setBody("err removing" + string(e.base().what()));
            callback(resp);
            return;
        },
        hash,
        ip
    );
    // omit callback
}
