#include <controllers/apiController.hh>

using std::stoi;

void apiController::getRemoveFromId(const HttpRequestPtr &req, 
        Callback &&callback, const string& sId)
{
    auto ip = req->peerAddr().toIp();
    auto id = stoi(sId);
    auto hash = ih->getHashFromId(id);
    db->execSqlAsync(queryDeleteUpload,
        [hash, callback, this](const Result& result) {
            if (result.empty()) {
                auto resp = HttpResponse::newNotFoundResponse();
                callback(resp);
                return;
            }
            auto flags = ih->deleteHash(hash);
            auto resp = HttpResponse::newHttpResponse();
            if(flags > 0) {
                resp->setStatusCode(k500InternalServerError);
                resp->setBody("something went wrong...");
            }
            else {
                resp->setStatusCode(k200OK);
                resp->setBody("Success");
            }
            callback(resp);
            return;
        },
        [callback](const DrogonDbException& e) {
            auto resp = HttpResponse::newHttpResponse();
            resp->setStatusCode(k500InternalServerError);
            resp->setBody("err removing" + string(e.base().what()));
            callback(resp);
            return;
        },
        hash,
        ip
    );
    // omit callback
}
