#include <controllers/apiController.hh>
#include <utils/sha256String.hh>
#include <utils/verifyJpeg.hh>
#include <fstream>

using std::runtime_error;
using std::ofstream;

void apiController::postUpload(const HttpRequestPtr& req, Callback&& callback)
{
    MultiPartParser file;
    if (file.parse(req) != 0 || file.getFiles().size() == 0) {
        throw runtime_error("err not image supplied");
        auto resp = HttpResponse::newHttpResponse();
        resp->setStatusCode(k500InternalServerError);
        resp->setBody("Fail");
        callback(resp);
        return;
    }
    auto& img = file.getFiles()[0];
    string data(img.fileContent());
    if (!verifyJpeg(data)) {
        throw runtime_error("err not valid jpg");
        auto resp = HttpResponse::newHttpResponse();
        resp->setStatusCode(k500InternalServerError);
        resp->setBody("not valid jpg");
        callback(resp);
        return;
    }
    string hash = sha256String(data);
    if (ih->checkExistHash(hash)) {
        auto resp = HttpResponse::newHttpResponse();
        resp->setStatusCode(k500InternalServerError);
        resp->setBody("Repost: " + hash);
        callback(resp);
        return;
    }
    auto ip = req->peerAddr().toIp();
    auto id = ih->getNewPostId();
    db->execSqlAsync(queryInsertUpload,
        [hash, data, callback, id, this]([[maybe_unused]]const Result& result) {
            auto flags = ih->upload(data, hash, id);
            auto resp = HttpResponse::newHttpResponse();
            if(flags > 0) {
                resp->setStatusCode(k500InternalServerError);
                resp->setBody("something went wrong...");
            }
            else {
                resp->setStatusCode(k200OK);
                resp->setBody("Success");
            }
            callback(resp);
            return;
        },
        [callback](const DrogonDbException& e) {
            auto resp = HttpResponse::newHttpResponse();
            resp->setStatusCode(k500InternalServerError);
            resp->setBody("err uploading" + string(e.base().what()));
            callback(resp);
            return;
        },
        id,
        hash,
        ip
    );
    // omit callback
}
