#ifndef IMAGE_HUB_HH
#define IMAGE_HUB_HH

#include <cstdint>
#include <pch.hh>
#include <vector>
#include <unordered_map>
#include <string>
#include <shared_mutex>
#include <queries.hh>
#include <local/imageHub/post.hh>

using std::string;
using std::unordered_map;
using std::vector;
using std::shared_mutex;
using std::function;
using std::pair;
using std::shared_lock;
using std::unique_lock;

class imageHub {
private:
    int currPostId = 0;
    vector<int> imageId;
    unordered_map<int, string> idToHash;
    unordered_map<string, int> hashToId;
    unordered_map<int, string> idToJpg;
    unordered_map<int, int> idToLikes;
    vector<pair<int, int>> top100;
    shared_mutex imageHubMutex;
    const string jpgExt = ".jpg";
    string imgPath;
    const int topRefreshSec = 5;
    const string dbName = "default";
    const string imgDir = "img_dir";
    function<void()> createTopLambda();
    void setFlag(uint32_t& flags, const int& indx) { flags |= (1 << indx); }
    uint32_t deleteRemove(int id, string hash);

public:
    imageHub();
    ~imageHub();
    uint32_t upload(const string& data, const string& hash, const int& id);
    json getTopPage(const int& page);
    uint32_t deleteHash(const string& hash);
    uint32_t deleteId(const int& id);
    post getImgId(const int& id);
    post getImgHash(const string& hash);
    post getImgRandom();
    int getIdFromHash(const string& hash);
    string getHashFromId(const int& id);
    bool likeFromId(const int& id);
    bool likeFromHash(const string& hash);
    bool checkExistId(const int& id);
    bool checkExistHash(const string& hash);
    int getLikesFromId(const int& id);
    int getLikesFromHash(const string& hash);
    int getNewPostId();

};

#endif // IMAGE_HUB_HH
