#ifndef QUERIES_HH
#define QUERIES_HH

#include <string>

using std::string;

/*
    CREATE TABLE posts (
    post_id INT PRIMARY KEY,
    post_filename VARCHAR(255) UNIQUE NOT NULL,
    ip_address INET NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
    );

    CREATE TABLE likes (
    post_id INT NOT NULL,  
    ip_address INET NOT NULL,  
    like_timestamp TIMESTAMP DEFAULT CURRENT_TIMESTAMP,  
    FOREIGN KEY (post_id) REFERENCES posts(post_id) ON DELETE CASCADE,  
    PRIMARY KEY (post_id, ip_address) 
    );

 */


const string queryUserUploads = R"(
        SELECT 
            post_id, post_filename, created_at 
        FROM 
            posts 
        WHERE 
            ip_address = $1 
            AND created_at >= CURRENT_TIMESTAMP - INTERVAL '1 day'
)";

const string queryInsertUpload = R"(
        INSERT INTO 
            posts (post_id, post_filename, ip_address, created_at) 
        VALUES 
            ($1, $2, $3, CURRENT_TIMESTAMP)
)";

const string queryInsertLike = R"(
        INSERT INTO 
            likes (post_id, ip_address) 
        VALUES ($1, $2) 
        ON CONFLICT (post_id, ip_address) 
        DO NOTHING
)";

const string queryDeleteUpload = R"(
    DELETE FROM 
        posts 
    WHERE 
        post_filename = $1
        AND ip_address = $2
    RETURNING *
)";

const string queryInitLoad = R"(
        SELECT 
            p.post_id, 
            p.post_filename, 
            COALESCE(COUNT(l.post_id), 0) AS like_count 
        FROM 
            posts p 
        LEFT JOIN 
            likes l ON p.post_id = l.post_id 
        GROUP BY 
            p.post_id, p.post_filename
)";

#endif // QUERIES_HH
