#include <utils/sha256String.hh>
#include <stdexcept>
#include <openssl/evp.h>

using std::runtime_error;

string sha256String(const string& str)
{
    EVP_MD_CTX *mdctx = EVP_MD_CTX_new();
    if (mdctx == nullptr) {
        throw runtime_error("Failed to create EVP_MD_CTX");
    }
    if (EVP_DigestInit_ex(mdctx, EVP_sha256(), nullptr) != 1) {
        EVP_MD_CTX_free(mdctx);
        throw runtime_error("Failed to initialize SHA-256");
    }
    if (EVP_DigestUpdate(mdctx, str.data(), str.size()) != 1) {
        EVP_MD_CTX_free(mdctx);
        throw runtime_error("Failed to update SHA-256 hash");
    }
    unsigned char hash[EVP_MAX_MD_SIZE];
    unsigned int hash_len;
    if (EVP_DigestFinal_ex(mdctx, hash, &hash_len) != 1) {
        EVP_MD_CTX_free(mdctx);
        throw runtime_error("Failed to finalize SHA-256");
    }
    EVP_MD_CTX_free(mdctx);
    std::string hash_hex;
    for (unsigned int i = 0; i < hash_len; ++i) {
        char hex[3];
        snprintf(hex, sizeof(hex), "%02x", hash[i]);
        hash_hex += hex;
    }
    return hash_hex;
}
